Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolScriptEditorInterface", J.api.JmolDropEditor);
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
